@@ -22,7 +22,6 @@ sub gather_violations_generic {
     my ( $self, $elem, $doc ) = @_;
 
     my %imported;
-    my %is_special = map { $_ => 1 } qw(use parent base constant);
 
     my $include_statements = $elem->find(sub { $_[1]->isa('PPI::Statement::Include') }) || [];
     for my $st (@$include_statements) {
@@ -30,7 +29,7 @@ sub gather_violations_generic {
         my $expr_qw = $st->find( sub { $_[1]->isa('PPI::Token::QuoteLike::Words'); }) or next;
 
         my $included_module = $st->schild(1);
-        next if $is_special{"$included_module"};
+        next if $included_module =~ /\A[a-z:]*\z/;
 
         if (@$expr_qw == 1) {
             my $expr = $expr_qw->[0];
